module Data.Char_Type(Char, String) where
import qualified Prelude()              -- do not import Prelude
import Primitives
import Data.List_Type

type String = [Char]
